ParseError

Enum ParseError 

#[non_exhaustive]
pub enum ParseError { Yaml(Error), InvalidVersion(u32), DuplicateId(String), InvalidSignalType { index: usize, signal_type: String, }, GeneratorAndPack { index: usize, }, MissingGeneratorOrPack { index: usize, }, MissingName { index: usize, }, PackNotMetrics { index: usize, }, InvalidId(String), UnexpectedField { index: usize, signal_type: String, field: String, }, }
Errors produced during v2 scenario parsing and validation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Yaml(Error)

The YAML could not be deserialized into the expected structure.



InvalidVersion(u32)

The version field is present but is not 2.



DuplicateId(String)

Two or more entries share the same id.



InvalidSignalType

An entry has an unrecognized signal_type.

Fields

index: usize

Zero-based index of the offending entry.

signal_type: String

The invalid signal type string.



GeneratorAndPack

An entry specifies both generator and pack.

Fields

index: usize

Zero-based index of the offending entry.



MissingGeneratorOrPack

An entry specifies neither generator/distribution nor pack.

Fields

index: usize

Zero-based index of the offending entry.



MissingName

An inline entry (non-pack) is missing the required name field.

Fields

index: usize

Zero-based index of the offending entry.



PackNotMetrics

A pack entry has a signal_type other than "metrics".

Fields

index: usize

Zero-based index of the offending entry.



InvalidId(String)

An entry id does not match the allowed pattern [a-zA-Z_][a-zA-Z0-9_]*.



UnexpectedField

An entry has a generator field that is incompatible with its signal_type.

For example, a signal_type: metrics entry must not have log_generator or distribution.

Fields

index: usize

Zero-based index of the offending entry.

signal_type: String

The signal type of the entry.

field: String

The field name that is not allowed for this signal type.