create_encoder

Function create_encoder 

pub fn create_encoder(
    config: &EncoderConfig,
) -> Result<Box<dyn Encoder>, SondaError>
Create a boxed Encoder from the given EncoderConfig.

Returns Err if the config refers to a feature-gated encoder whose Cargo feature was not enabled at compile time.