Syslog

Struct Syslog 

pub struct Syslog { /* private fields */ }
Encodes LogEvents in RFC 5424 syslog format.

The hostname and app-name fields in the syslog header are configurable at construction time. They default to "sonda" and "sonda" respectively.

Only encode_log is supported. encode_metric returns an error because syslog is a log-only format.

Implementations

Source

impl Syslog

pub fn new(hostname: Option<String>, app_name: Option<String>) -> Self

Create a new Syslog encoder with the given hostname and app-name.

Arguments
  • hostname — The HOSTNAME field. Defaults to "sonda" if None.
  • app_name — The APP-NAME field. Defaults to "sonda" if None.