pub struct PrometheusText { /* private fields */ }Expand description
Encodes MetricEvents into Prometheus text exposition format (version 0.0.4).
Output format for a metric with labels:
metric_name{label1="val1",label2="val2"} value timestamp_ms\nOutput format for a metric with no labels:
metric_name value timestamp_ms\nThe timestamp is in milliseconds since the Unix epoch (integer).
Label values are escaped: \ → \\, " → \", newline → \n.
When precision is set, metric values are formatted to the specified number
of decimal places (e.g., precision=2 formats 99.60573 as 99.61).
Implementations